@@ -1,29 +1,27 @@
 # -*- coding: utf-8 -*-
 
-"""
-Copyright (c) 2013 Petr Jerabek
-
-Permission is hereby granted, free of charge, to any person
-obtaining a copy of this software and associated documentation
-files (the "Software"), to deal in the Software without
-restriction, including without limitation the rights to use,
-copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following
-conditions:
-
-The above copyright notice and this permission notice shall be
-included in all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-OTHER DEALINGS IN THE SOFTWARE.
-"""
+# Copyright (c) 2013 Petr Jerabek
+#
+# Permission is hereby granted, free of charge, to any person
+# obtaining a copy of this software and associated documentation
+# files (the "Software"), to deal in the Software without
+# restriction, including without limitation the rights to use,
+# copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the
+# Software is furnished to do so, subject to the following
+# conditions:
+#
+# The above copyright notice and this permission notice shall be
+# included in all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
+# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+# OTHER DEALINGS IN THE SOFTWARE.
 
 from __future__ import unicode_literals
 
@@ -52,21 +50,25 @@ class Api(object):
             self.login(username, password)
 
     def login(self, username=None, password=None):
-        """Command `Login`
+        """
         User login to API
-        :param username: Username for login
-        :param password: Password
-        https://soap.subreg.cz/manual/?cmd=Login
+
+        :param str username: Username for login
+        :param str password: Password
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Login
         """
         kwargs = {'login': username, 'password': password}
         response = self._request('Login', kwargs)
         self.token = response['ssid']
 
     def check_domain(self, domain):
-        """Command `Check_Domain`
+        """
         Check if domain is available or not
-        :param domain: Domain for check availability
-        https://soap.subreg.cz/manual/?cmd=Check_Domain
+
+        :param str domain: Domain for check availability
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Check_Domain
         """
         kwargs = {'domain': domain}
         response = self._request('Check_Domain', kwargs)
@@ -75,47 +77,55 @@ class Api(object):
         return False
 
     def info_domain(self, domain):
-        """Command `Info_Domain`
+        """
         Get informations about a single domain from your account
-        :param domain: Domain name for requested informations
-        https://soap.subreg.cz/manual/?cmd=Info_Domain
+
+        :param str domain: Domain name for requested informations
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Info_Domain
         """
         kwargs = {'domain': domain}
         response = self._request('Info_Domain', kwargs)
         return response
 
     def info_domain_cz(self, domain):
-        """Command `Info_Domain_CZ`
+        """
         Get informations about a single .CZ domain
-        :param domain: Domain name for requested informations
-        https://soap.subreg.cz/manual/?cmd=Info_Domain_CZ
+
+        :param str domain: Domain name for requested informations
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Info_Domain_CZ
         """
         kwargs = {'domain': domain}
         response = self._request('Info_Domain_CZ', kwargs)
         return response
 
     def domains_list(self):
-        """Command `Domains_List`
+        """
         Get all domains from your account
+
         :return dict
             :key `domains`: dict of domains
                 :key `name`: Domain name
                 :key `expire`: Domain expiration date
             :key `count`: Domains count
-        https://soap.subreg.cz/manual/?cmd=Domains_List
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Domains_List
         """
         return self._request('Domains_List')
 
     def set_autorenew(self, domain, autorenew):
-        """Command `Set_Autorenew`
+        """
         Set autorenew policy for your domain.
         By default, domain is deleted when it expire.
         You can set autorenew flag to AUTORENEW, then it will use your credit
         to renew automatically. RENEWONCE will cause renew only for next year.
-        :param domain: Registered domain
-        :param autorenew: Autorenew setting, allowed values:
+
+        :param str domain: Registered domain
+        :param str autorenew: Autorenew setting, allowed values:
             EXPIRE, AUTORENEW, RENEWONCE
-        https://soap.subreg.cz/manual/?cmd=Set_Autorenew
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Set_Autorenew
         """
         if autorenew in ['EXPIRE', 'AUTORENEW', 'RENEWONCE']:
             kwargs = {'domain': domain, 'autorenew': autorenew}
@@ -127,206 +137,233 @@ class Api(object):
         return False
 
     def create_contact(self, **kwargs):
-        """Command `Create_Contact`
+        """
         Create contact in Subreg DB
-        https://soap.subreg.cz/manual/?cmd=Create_Contact
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Create_Contact
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def update_contact(self, **kwargs):
-        """Command `Update_Contact`
+        """
         Update contact
-        https://soap.subreg.cz/manual/?cmd=Update_Contact
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Update_Contact
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def info_contact(self, contact_id):
-        """Command `Info_Contact`
+        """
         Get informations about a single contact from your account
-        :param contact_id: ID of your querying contact
-        https://soap.subreg.cz/manual/?cmd=Info_Contact
+
+        :param int contact_id: ID of your querying contact
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Info_Contact
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def contacts_list(self):
-        """Command `Contacts_List`
+        """
         Get all contacts from your account
-        https://soap.subreg.cz/manual/?cmd=Contacts_List
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Contacts_List
         """
         return self._request('Contacts_List')
 
     def check_object(self, _id, _object):
-        """Command `Check_Object`
+        """
         Check if object is available or not (only CZ,EE)
-        :param _id: ID for check availability
-        :param _object: contact, nsset, keyset (only CZ, EE)
-        https://soap.subreg.cz/manual/?cmd=Check_Object
+
+        :param int _id: ID for check availability
+        :param str _object: contact, nsset, keyset (only CZ, EE)
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Check_Object
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def info_object(self, _id, _object):
-        """Command `Info_Object`
+        """
         Info about NIC object (only CZ,EE)
-        :param _id: ID for info
-        :param _object: contact, nsset, keyset (only CZ, EE)
-        https://soap.subreg.cz/manual/?cmd=Info_Object
+
+        :param int _id: ID for info
+        :param str _object: contact, nsset, keyset (only CZ, EE)
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Info_Object
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def make_order(self, **kwargs):
-        """Command `Make_Order`
+        """
         Create a new order (CreateDomain, ModifyDomain, RenewDomain, ... )
-        :arg type:
-            https://soap.subreg.cz/manual/?cmd=Create_Domain
-            https://soap.subreg.cz/manual/?cmd=Transfer_Domain
-            https://soap.subreg.cz/manual/?cmd=AccountTransfer_Domain
-            https://soap.subreg.cz/manual/?cmd=TransferApprove_Domain
-            https://soap.subreg.cz/manual/?cmd=TransferDeny_Domain
-            https://soap.subreg.cz/manual/?cmd=TransferCancel_Domain
-            https://soap.subreg.cz/manual/?cmd=SKChangeOwner_Domain
-            https://soap.subreg.cz/manual/?cmd=Modify_Domain
-            https://soap.subreg.cz/manual/?cmd=ModifyNS_Domain
-            https://soap.subreg.cz/manual/?cmd=Delete_Domain
-            https://soap.subreg.cz/manual/?cmd=Restore_Domain
-            https://soap.subreg.cz/manual/?cmd=Renew_Domain
-            https://soap.subreg.cz/manual/?cmd=Backorder_Domain
-            https://soap.subreg.cz/manual/?cmd=Preregister_Domain
-            https://soap.subreg.cz/manual/?cmd=Create_Object
-            https://soap.subreg.cz/manual/?cmd=Transfer_Object
-            https://soap.subreg.cz/manual/?cmd=Update_Object
-            https://soap.subreg.cz/manual/?cmd=TransferRU_Request
-            https://soap.subreg.cz/manual/?cmd=Create_Host
-            https://soap.subreg.cz/manual/?cmd=Update_Host
-            https://soap.subreg.cz/manual/?cmd=Delete_Host
-        https://soap.subreg.cz/manual/?cmd=Make_Order
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Make_Order
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def info_order(self, order_id):
-        """Command `Info_Order`
+        """
         Info about existing order
-        :param order_id: Order ID
-        https://soap.subreg.cz/manual/?cmd=Info_Order
+
+        :param int order_id: Order ID
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Info_Order
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def get_credit(self):
-        """Command `Get_Credit`
+        """
         Get status of your credit
-        https://soap.subreg.cz/manual/?cmd=Get_Credit
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Get_Credit
         """
         return self._request('Get_Credit')
 
     def get_accountings(self, from_date, to_date):
-        """Command `Get_Accountings`
+        """
         Get financial statements from account
+
         :param from_date: Date (YYYY-mm-dd)
         :param to_date: Date (YYYY-mm-dd)
-        https://soap.subreg.cz/manual/?cmd=Get_Accountings
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Get_Accountings
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def client_payment(self, username, amount, currency):
-        """Command `Client_Payment`
+        """
         Add credit to your sub-user. This command WILL generate invoice,
         if you want just correct current amount of credit for any reason,
         please use command Credit_Correction.
-        :param username: Login username of the use you want to add credit
-        :param amount: Amount of money to add
-        :param currency: Currency of added credit
-        https://soap.subreg.cz/manual/?cmd=Client_Payment
+
+        :param str username: Login username of the use you want to add credit
+        :param str amount: Amount of money to add
+        :param str currency: Currency of added credit
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Client_Payment
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def credit_correction(self, username, amount, reason):
-        """Command `Credit_Correction`
+        """
         Correct credit amount of your sub-users. The amount you specify in this
         command will be added to current amount. Use negative values for
         subtracting credit. Please note that currency will depend on
         current user setting.
-        :param username: Login username of the user you want to add credit
-        :param amount: Amount of money to add/subtract
-        :param reason: Human readable reason for this operation
-        https://soap.subreg.cz/manual/?cmd=Credit_Correction
+
+        :param str username: Login username of the user you want to add credit
+        :param float amount: Amount of money to add/subtract
+        :param str reason: Human readable reason for this operation
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Credit_Correction
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def pricelist(self):
-        """Command `Pricelist`
+        """
         Get pricelist from account
-        https://soap.subreg.cz/manual/?cmd=Pricelist
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Pricelist
         """
         return self._request('Pricelist')
 
     def prices(self, tld):
-        """Command `Prices`
+        """
         Get Prices for TLD from account
-        :type tld: Requested TLD
-        https://soap.subreg.cz/manual/?cmd=Prices
+
+        :type str tld: Requested TLD
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Prices
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def get_pricelist(self, pricelist):
-        """Command `Get_Pricelist`
+        """
         Return all price information in specified pricelist.
-        :param pricelist: Identificator of the pricelist you want to download.
-        https://soap.subreg.cz/manual/?cmd=Get_Pricelist
+
+        :param str pricelist: Identificator of the pricelist you want to download.
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Get_Pricelist
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def set_prices(self, pricelist, tld, currency, prices=None):
-        """Command `Set_Prices`
+        """
         Change prices in specified pricelist.
-        :param pricelist: Identificator of the pricelist you want to download.
-        :param tld: TLD for which you want to change prices.
-        :param currency: Currency code the prices use.
-        :param prices: List of operations with price
-        https://soap.subreg.cz/manual/?cmd=Set_Prices
+
+        :param str pricelist: Identificator of the pricelist you want to download.
+        :param str tld: TLD for which you want to change prices.
+        :param str currency: Currency code the prices use.
+        :param str prices: List of operations with price
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Set_Prices
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def download_document(self, document_id):
-        """Command `Download_Document`
+        """
         Get document information and base64 encoded document that you have
         uploaded or generated on your account.
-        :param document_id: Document ID, you can get it in response of
+
+        :param int document_id: Document ID, you can get it in response of
                             `Upload_Document` or by `List_Documents`.
-        https://soap.subreg.cz/manual/?cmd=Download_Document
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Download_Document
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def upload_document(self, name, document, _type=None, filetype=None):
-        """Command `Upload_Document`
+        """
         Upload document to your account, for use as identification document,
         registration request etc.
-        :param name: Filename of the document, including extension
-        :param document: base64 encoded document
-        :param _type: Type of the document
+
+        :param str name: Filename of the document, including extension
+        :param str document: base64 encoded document
+        :param str _type: Type of the document
                      (https://soap.subreg.cz/manual/?cmd=Document_Types)
-        :param filetype: MIME type of the file
-        https://soap.subreg.cz/manual/?cmd=Upload_Document
+        :param str filetype: MIME type of the file
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Upload_Document
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def list_documents(self):
-        """Command `List_Documents`
+        """
         List documents uploaded or generated on your account.
-        https://soap.subreg.cz/manual/?cmd=List_Documents
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=List_Documents
         """
         return self._request('List_Documents')
 
     def users_list(self):
-        """Command `Users_List`
+        """
         Retrieve list of all your sub-users
-        https://soap.subreg.cz/manual/?cmd=Users_List
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Users_List
         """
         return self._request('Users_List')
 
     def get_dns_zone(self, domain):
-        """Command `Get_DNS_Zone`
+        """
         List of DNS records for specified domain.
-        :param domain: Registered domain
-        https://soap.subreg.cz/manual/?cmd=Get_DNS_Zone
+
+        :param str domain: Registered domain
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Get_DNS_Zone
         """
         kwargs = {'domain': domain}
         response = self._request('Get_DNS_Zone', kwargs)
@@ -336,11 +373,13 @@ class Api(object):
             return []
 
     def add_dns_zone(self, domain, template=None):
-        """Command `Add_DNS_Zone`
+        """
         Add domain to DNS using previously created template.
-        :param domain: Registered domain
-        :param template: DNS template ID or template name
-        https://soap.subreg.cz/manual/?cmd=Add_DNS_Zone
+
+        :param str domain: Registered domain
+        :param str template: DNS template ID or template name
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Add_DNS_Zone
         """
         kwargs = {'domain': domain}
         if not template:
@@ -352,40 +391,49 @@ class Api(object):
             return False
 
     def delete_dns_zone(self, domain):
-        """Command `Delete_DNS_Zone`
+        """
         Remove ALL DNS records for specified domain.
-        :param domain: Registered domain
-        https://soap.subreg.cz/manual/?cmd=Delete_DNS_Zone
+
+        :param str domain: Registered domain
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Delete_DNS_Zone
         """
         kwargs = {'domain': domain}
         response = self._request('Delete_DNS_Zone', kwargs)
         return response
 
     def set_dns_zone(self, domain, records):
-        """Command `Set_DNS_Zone`
+        """
         Specify complete set of records for certain zone.
         Specified records will replace ALL present records.
-        :param domain: Registered domain
-        :param records: List of dicts of records
-        https://soap.subreg.cz/manual/?cmd=Set_DNS_Zone
+
+        :param str domain: Registered domain
+        :param list records: List of dicts of records
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Set_DNS_Zone
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def add_dns_record(self, domain, record):
-        """Command `Add_DNS_Record`
+        """
         Add DNS record to zone.
-        :param domain: Registered domain
-        :param record: dict wirh params:
-            `name` Hostname (part of hostname, without registered domain)
-            `type` Type of DNS record
-            `content` Value of this record (IP address, hostname, text value,..)
-            `prio` Priority of this record (MX records only)
-            `ttl` TTL value
-        https://soap.subreg.cz/manual/?cmd=Add_DNS_Record
+
+        :param str domain: Registered domain
+        :param dict record: dict with params
+
+            :key name: Hostname (part of hostname, without registered domain)
+            :key type: Type of DNS record
+            :key content: Value of this record (IP address, hostname, text
+                value,..)
+            :key prio: Priority of this record (MX records only)
+            :key ttl: TTL value
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Add_DNS_Record
         """
         if not isinstance(record, dict):
             raise TypeError
-        # remove leading .
+            # remove leading .
         record['content'] = re.sub('\.$', '', record['content'])
         kwargs = {'domain': domain, 'record': record}
         try:
@@ -395,16 +443,21 @@ class Api(object):
             return False
 
     def modify_dns_record(self, domain, record):
-        """Command `Modify_DNS_Record`
-        :param domain: Registered domain
-        :param record: dict with ID of existing record
-            `id` ID of existing record
-            `name` Hostname (part of hostname, without registered domain)
-            `type` Type of DNS record
-            `content` Value of this record (IP address, hostname, text value,..)
-            `prio` Priority of this record (MX records only)
-            `ttl` TTL value
-        https://soap.subreg.cz/manual/?cmd=Modify_DNS_Record
+        """
+        Midify DNS record at zone.
+
+        :param str domain: Registered domain
+        :param dict record: dict with ID of existing record
+
+            :key id: ID of existing record
+            :key name: Hostname (part of hostname, without registered domain)
+            :key type: Type of DNS record
+            :key content: Value of this record (IP address, hostname, text
+                value,..)
+            :key prio: Priority of this record (MX records only)
+            :key ttl: TTL value
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Modify_DNS_Record
         """
         if not isinstance(record, dict):
             raise TypeError
@@ -422,11 +475,13 @@ class Api(object):
             return False
 
     def delete_dns_record(self, domain, record_id):
-        """Command `Delete_DNS_Record`
+        """
         Remove DNS record from zone.
-        :param domain: Registered domain
-        :param record_id: ID of existing record
-        https://soap.subreg.cz/manual/?cmd=Delete_DNS_Record
+
+        :param str domain: Registered domain
+        :param int record_id: ID of existing record
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Delete_DNS_Record
         """
         if not record_id:
             raise TypeError
@@ -438,31 +493,245 @@ class Api(object):
             return False
 
     def poll_get(self):
-        """Command `POLL_Get`
+        """
         Get current poll message
-        https://soap.subreg.cz/manual/?cmd=POLL_Get
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=POLL_Get
         """
         return self._request('POLL_Get')
 
     def poll_ack(self, poll_id):
-        """Command `POLL_Ack`
+        """
         Ack current poll message
-        :param poll_id: POLL ID
-        https://soap.subreg.cz/manual/?cmd=POLL_Ack
+
+        :param int poll_id: POLL ID
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=POLL_Ack
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def oib_search(self, oib):
-        """Command `OIB_Search`
+        """
         List domains registered for certain OIB, and get the number of domains
         possible to register for this OIB.
-        :param oib: Croatian OIB number
-        https://soap.subreg.cz/manual/?cmd=OIB_Search
+
+        :param str oib: Croatian OIB number
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=OIB_Search
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    # -- Orders ----------------------------------------------------------------
+
+    def create_domain(self):
+        """Order: `Create_Domain`
+        Create a new domain.
+        For DNSSEC extension please see full
+        specification `here <https://soap.subreg.cz/manual/?cmd=DNSSEC>`_
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Create_Domain
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def transfer_domain(self):
+        """
+        Transfer domain between two registrars or two account
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Transfer_Domain
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def account_transfer_domain(self):
+        """
+        Transfer domain between two Subreg.CZ accounts.
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=AccountTransfer_Domain
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def transfer_approve_domain(self):
+        """
+        Transfer Approve domain between two registrars
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=TransferApprove_Domain
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def transfer_deny_domain(self):
+        """
+        Transfer Deny domain between two registrars
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=TransferDeny_Domain
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def transfer_cancel_domain(self):
+        """
+        Transfer Cancel domain between two registrars
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=TransferCancel_Domain
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def sk_change_owner_domain(self):
+        """
+        Initiate owner change for .SK domain. During processing of this order,
+        filled form will be generated onto your account.
+        You can then download it using our web interface or using
+        `Download_Document <https://soap.subreg.cz/manual/?cmd=Download_Document>`_.
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=SKChangeOwner_Domain
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def modify_domain(self):
+        """
+        Modify existing domain to new values.
+        For DNSSEC extension please see full
+        specification `here <https://soap.subreg.cz/manual/?cmd=DNSSEC>`_.
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Modify_Domain
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def modify_ns_domain(self):
+        """
+        Modify existing domain to new values.
+        For DNSSEC extension please see full
+        specification `here <https://soap.subreg.cz/manual/?cmd=DNSSEC>`_.
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=ModifyNS_Domain
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def delete_domain(self):
+        """
+        Delete a existing domain from your account
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Delete_Domain
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def restore_domain(self):
+        """
+        Restore a deleted domain from your account
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Restore_Domain
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def renew_domain(self):
+        """
+        Renew a existing domain from your account
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Renew_Domain
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def backorder_domain(self):
+        """
+        Create a backorder order. We will register domain after deletion
+        from registry
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Backorder_Domain
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def preregister_domain(self):
+        """
+        This order type is for new TLDs or liberation rules of existing TLDs
+        domain pre-registration
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Preregister_Domain
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def create_object(self):
+        """
+        Creates new nsset or keyset.
+        Only for registries with such capability (for example CZ-NIC or Eurid)
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Create_Object
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def transfer_object(self):
+        """
+        Transfer object between two registrars (CZ-NIC)
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Transfer_Object
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def update_object(self):
+        """
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Update_Object
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def transfer_ru_request(self):
+        """
+        Transfer (change partner) of all domains on specified NIC-D account to
+        Subreg.CZ.
+        If you want to transfer just one .ru domain, you need to create new
+        NIC-D account for that domain.
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=TransferRU_Request
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def create_host(self):
+        """
+        Create new delegated host object.
+        It is possible to specify multiple IPv4 and IPv6 addresses of the host.
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Create_Host
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def update_host(self):
+        """
+        Change IP addresses of delegated host object.
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Update_Host
+        .. exception:: NotImplementedError
+        """
+        raise NotImplementedError
+
+    def delete_host(self):
+        """
+        Delete delegated host object.
+        It is only possible to delete host when it is no longer used.
+
+        .. seealso:: https://soap.subreg.cz/manual/?cmd=Delete_Host
+        .. exception:: NotImplementedError
         """
         raise NotImplementedError
 
     def set_google_mx_records(self, domain):
-        """Set Google MX rerods
+        """
+        Set Google MX rerods.
         Specified records will replace ALL present MX records.
         """
         records = self.get_dns_zone(domain)
@@ -497,11 +766,9 @@ class Api(object):
         if response:
             if response['status'] == 'error':
                 raise ApiError(
-                    'Major: {} Minor: {} Text: {}'.format(
-                        response['error']['errorcode']['major'],
-                        response['error']['errorcode']['minor'],
-                        response['error']['errormsg'],
-                    )
+                    message=response['error']['errormsg'],
+                    major=response['error']['errorcode']['major'],
+                    minor=response['error']['errorcode']['minor']
                 )
             return response.get('data')
         raise Exception('Fatal error.')
